<?php

namespace Picea\ControlStructure;

class ForeachToken implements ControlStructure {

    public array $token = [ "foreach", "endforeach" ];

    public function parse(/*\Picae\Compiler\Context*/ &$context, ?string $arguments, string $token) {
        switch($token) {
            case "foreach":
                $name = "$".uniqid("foreach_");
                
                $stack = array_filter($context->iterationStack ?? [], function($item) {
                    return ! $item['or'];
                });
                
                $count = count($stack);

                if ( $count > 0 ) {
                    $name .= "[" . end($stack)['uid'] . "]";
                }

                $context->iterationStack[] = [
                    'or' => false,
                    'uid' => $name,
                    'token' => 'endforeach',
                ];

                return "<?php foreach ($arguments): $name = ( $name ?? 0 ) + 1; ; ?>";
                
            case "endforeach":
                $last = end($context->iterationStack);

                if ( $last['or'] === false ) {
                    $output = "<?php endforeach; ?>";
                }
                else {
                    $output = "<?php endif; unset({$last['uid']}) ?>";
                }

                array_pop($context->iterationStack);
                
                return $output;
        }
    }
}
