<?php

namespace Picea\Extension;

use Picea\Compiler\Context;

class LanguageExtension implements Extension, FunctionExtension {

    public array $tokens = [ "lang", "_", "language.set" ];

    public string $currentLanguage = "";

    protected LanguageHandler $languageHandler;

    public function __construct(LanguageHandler $handler) {
        $this->languageHandler = $handler;
    }

    public function exportFunctions(): array
    {
        return [
            '_' => 'relativeLang',
            'lang' => 'absoluteLang',
        ];
    }

    public function parse(/*\Picae\Compiler\Context*/ &$context, ?string $arguments, string $token) : string
    {
        switch($token) {
            case "language.set":
                return "<?php \$picea->compiler->getExtensionFromToken('$token')->currentLanguage = $arguments; ?>";

            case "lang":
                return "<?php echo \$picea->compiler->getExtensionFromToken('$token')->absoluteLang($arguments) ?>";

            case "_":
                return "<?php echo \$picea->compiler->getExtensionFromToken('$token')->relativeLang($arguments) ?>";
        }

        return "";
    }

    public function register(Context $context) : void
    {
    }

    public function relativeLang(string $key, array $variables = []) #: array|string
    {
        return $this->languageHandler->languageFromKey("{$this->currentLanguage}.{$key}", $variables);
    }

    public function absoluteLang(string $key, array $variables = []) #: array|string
    {
        return $this->languageHandler->languageFromKey($key, $variables);
    }
}
